yt.utilities.lib.embree\_mesh.mesh\_traversal module
====================================================

.. automodule:: yt.utilities.lib.embree_mesh.mesh_traversal
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
